@@ -2,7 +2,7 @@
  * 
  * Copyright 1992-1998 Werner Almesberger
  * Copyright 1999-2007 John Coffman
- * Copyright 2009-2010 Joachim Wiedorn
+ * Copyright 2009-2011 Joachim Wiedorn
  * All rights reserved.
  * 
  * Licensed under the terms contained in the file 'COPYING'
@@ -85,7 +85,7 @@ void boot_image(char *spec,IMAGE_DESCR *descr)
 		check_size(spec,setup,sectors);
 	else {
 		if (hdr.start % PAGE_SIZE)
-			die("Can't load kernel at mis-aligned address 0x%08lx\n",hdr.start);
+			die("Can't load kernel at mis-aligned address 0x%08x\n",hdr.start);
 		descr->flags |= FLAG_LOADHI;	/* load kernel high */
 		hi_sectors = sectors - setup;	/* number of sectors loaded high */
 		hi_sectors *= 6;            	/* account for decompression */
@@ -334,13 +334,6 @@ void boot_other(char *loader,char *boot,char *part,IMAGE_DESCR *descr)
 
     if (!loader) loader = DFL_CHAIN;
 #ifdef LCF_BUILTIN
-#ifndef LCF_SOLO_CHAIN
-    if (strstr(loader,"os2")) {
-	chain = &Os2_d;
-	cname = "OS/2";
-    }
-    else
-#endif
     {
 	chain = &Chain;
 	cname = "CHAIN";
