@@ -2,7 +2,7 @@
  * 
  * Copyright 1992-1998 Werner Almesberger
  * Copyright 1999-2005 John Coffman
- * Copyright 2009-2011 Joachim Wiedorn
+ * Copyright 2009-2015 Joachim Wiedorn
  * All rights reserved.
  * 
  * Licensed under the terms contained in the file 'COPYING'
@@ -276,7 +276,7 @@ int main(int argc, char *argv[])
 	fprintf(stderr, "*****Fatal:  INT != 4\n");
 	return 1;
     }
-    if (sizeof(long)>sizeof(int))
+    if (sizeof(int32_t)>sizeof(int))
 	fprintf(stderr, "**Note:  LONG is bigger than INT\n");
 	
     return 0;
