@@ -2,7 +2,7 @@
  * 
  * Copyright 1992-1998 Werner Almesberger
  * Copyright 1999-2005 John Coffman
- * Copyright 2009-2011 Joachim Wiedorn
+ * Copyright 2009-2015 Joachim Wiedorn
  * All rights reserved.
  * 
  * Licensed under the terms contained in the file 'COPYING'
@@ -19,6 +19,9 @@
 #include <sys/stat.h>
 #endif
 
+#include <inttypes.h>
+#define PTR_WIDTH ((int) (sizeof(intptr_t) * 2))
+
 #ifndef PAGE_SIZE
 # define PAGE_SIZE 4096U
 #endif
