@@ -1,7 +1,7 @@
 /* edit.c  -  Bitmap file manipulation and editing
  * 
  * Copyright 2002-2004 John Coffman
- * Copyright 2009-2011 Joachim Wiedorn
+ * Copyright 2009-2015 Joachim Wiedorn
  * All rights reserved.
  * 
  * Licensed under the terms contained in the file 'COPYING'
@@ -193,7 +193,7 @@ static	union {
 	} tm;
 static	MENUTABLE *menu = &tm.mt;
 static	BITMAPLILOHEADER *lh = (void*)(tm.buffer +
-    			((long)&tm.mt.row - (long)&tm.bmlh.row));
+    			((intptr_t)&tm.mt.row - (intptr_t)&tm.bmlh.row));
 
 /* a convenience definition */
 #define mn tm.mt
