@@ -2,7 +2,7 @@
  * 
  * Copyright 1992-1998 Werner Almesberger
  * Copyright 1999-2007 John Coffman
- * Copyright 2009-2014 Joachim Wiedorn
+ * Copyright 2009-2015 Joachim Wiedorn
  * All rights reserved.
  * 
  * Licensed under the terms contained in the file 'COPYING'
@@ -193,11 +193,12 @@ extern int has_partitions_beta(dev_t dev);	/* defined in geometry.c */
 				"l=%d, ll=%d, f=%d, d=%d, ld=%d\n",
 			MAX_IMAGES, (int)sizeof(char),
 			(int)sizeof(short), (int)sizeof(int),
-			(int)sizeof(long), (int)sizeof(
+			(int)sizeof(int32_t), (int)sizeof(
 #if !__MSDOS__
-			long
+			int64_t),
+#else
+			int32_t),
 #endif /* !__MSDOS__ */
- 			     long),
 			(int)sizeof(float), (int)sizeof(double),
 			(int)sizeof(long double)
 			);
@@ -719,7 +720,7 @@ fprintf(errstd,"argc=%d, *argv=%s, ch=%c param=%s\n", argc, *argv, ch, param);
 	        if (*(param = (*argv)+2)) argc++;
 	        else if (argc) param = *++argv;
 	        else reboot_arg = "";
-	        
+
 		while (argc) {
 			if (!reboot_arg)
 			    *(reboot_arg = alloc(strlen(param)+1)) = 0;
@@ -731,9 +732,6 @@ fprintf(errstd,"argc=%d, *argv=%s, ch=%c param=%s\n", argc, *argv, ch, param);
 			strcat(reboot_arg, param);
 			argc--;
 		    }
-#if 0
-fprintf(errstd,"REBOOT=\"%s\"\n", reboot_arg);		    
-#endif
 		break;
 #if !__MSDOS__
 	    case 's':
@@ -767,7 +765,7 @@ fprintf(errstd,"REBOOT=\"%s\"\n", reboot_arg);
 	            param = *++argv;
 	            argc--;
 	        }
-	        if (param) 
+	        if (param)
 		    verbose = to_number(param);
 		else
 	            if (verbose<0) verbose = 1;
@@ -829,18 +827,15 @@ fprintf(errstd,"REBOOT=\"%s\"\n", reboot_arg);
         }
         printf("  * Copyright (C) 1992-1998 Werner Almesberger  (until v20)\n"
                "  * Copyright (C) 1999-2007 John Coffman  (until v22)\n"
-               "  * Copyright (C) 2009-2014 Joachim Wiedorn  (since v23)\n"
+               "  * Copyright (C) 2009-2015 Joachim Wiedorn  (since v23)\n"
                "This program comes with ABSOLUTELY NO WARRANTY. This is free software \n"
                "distributed under the BSD License (3-clause). Details can be found in \n"
                "the file COPYING, which is distributed with this software.\n"
         );
         if (verbose>0) {
 #if !__MSDOS__
-#include <sys/utsname.h>
+  #include <sys/utsname.h>
           struct utsname buf;
-#endif
-          printf("Compiled at %s on %s%s\n", __TIME__, __DATE__, semi);
-#if !__MSDOS__
           if (verbose>=2 && uname(&buf)==0) {
             printf("Running %s kernel %s on %s\n",
               buf.sysname, buf.release, buf.machine);
