@@ -2,7 +2,7 @@
  * 
  * Copyright 1992-1998 Werner Almesberger
  * Copyright 1999-2006 John Coffman
- * Copyright 2009-2014 Joachim Wiedorn
+ * Copyright 2009-2015 Joachim Wiedorn
  * All rights reserved.
  * 
  * Licensed under the terms contained in the file 'COPYING'
@@ -19,7 +19,7 @@
 #if !__MSDOS__
 #define INT4 int
 #else
-#define INT4 long
+#define INT4 int32_t
 #endif /* !__MSDOS__ */
 
 /* This is the stuff to check the configuration:
