@@ -1,6 +1,6 @@
-/* shs2.h -- NIST secure hash standard */
-/*
-   Written 2 September 1992, Peter C. Gutmann,
+/* shs2.c  -  NIST proposed Secure Hash Standard
+
+   Written 2 September 1992, Peter C. Gutmann;
    This implementation placed in the public domain.
 
    Transcribed 2 October 2001, John Coffman.
